Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(291)

Unified Diff: net/quic/quic_crypto_server_stream_test.cc

Issue 2176323002: Deprecate FLAGS_quic_disable_pre_30. Remove QUIC versions [25-29]. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@127879468
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/quic/quic_crypto_server_stream_test.cc
diff --git a/net/quic/quic_crypto_server_stream_test.cc b/net/quic/quic_crypto_server_stream_test.cc
index 40e252204c92a9c28bf58ba7829a4c1d651d49af..136a18c900cb4a0ab80308e9780914fff435466c 100644
--- a/net/quic/quic_crypto_server_stream_test.cc
+++ b/net/quic/quic_crypto_server_stream_test.cc
@@ -427,7 +427,6 @@ TEST_P(QuicCryptoServerStreamTest, ZeroRTT) {
}
TEST_P(QuicCryptoServerStreamTest, FailByPolicy) {
- FLAGS_quic_disable_pre_30 = true;
FLAGS_quic_deprecate_kfixd = true;
Initialize();
InitializeFakeClient(/* supports_stateless_rejects= */ false);
@@ -441,7 +440,6 @@ TEST_P(QuicCryptoServerStreamTest, FailByPolicy) {
}
TEST_P(QuicCryptoServerStreamTest, MessageAfterHandshake) {
- FLAGS_quic_disable_pre_30 = true;
FLAGS_quic_deprecate_kfixd = true;
Initialize();
CompleteCryptoHandshake();
@@ -456,7 +454,6 @@ TEST_P(QuicCryptoServerStreamTest, MessageAfterHandshake) {
}
TEST_P(QuicCryptoServerStreamTest, BadMessageType) {
- FLAGS_quic_disable_pre_30 = true;
FLAGS_quic_deprecate_kfixd = true;
Initialize();
@@ -567,9 +564,9 @@ TEST_P(QuicCryptoServerStreamTest, CancelRPCBeforeVerificationCompletes) {
// Tests that the client can close the connection while the remote strike
// register verification RPC is still pending.
// Set version to QUIC_VERSION_25 as QUIC_VERSION_26 and later don't support
// asynchronous strike register RPCs.
- supported_versions_ = {QUIC_VERSION_25};
+ supported_versions_ = {QUIC_VERSION_32};
Initialize();
if (!AsyncStrikeRegisterVerification()) {
return;
@@ -567,9 +564,9 @@ TEST_P(QuicCryptoServerStreamTest, CancelRPCBeforeVerificationCompletes) {
// Tests that the client can close the connection while the remote strike
// register verification RPC is still pending.
- // Set version to QUIC_VERSION_25 as QUIC_VERSION_26 and later don't support
+ // Set version to QUIC_VERSION_32 as QUIC_VERSION_33 and later don't support
// asynchronous strike register RPCs.

Powered by Google App Engine
This is Rietveld 408576698